# frozen_string_literal: true

# app/hermes/models/concerns/common_field.rb
# app/controllers/concerns/test_concern.rb

module Hermes
  module Concerns
    # Handles statuses relationships
    module AlsIdConcern
      extend ActiveSupport::Concern

      included do
        field :als_id, type: String

        index({ als_id: 1 }, {sparse: true, background: true, unique: true})

        def als_id=(hex)
          if self.class
                 .only(:als_id)
                 .find_by(als_id: hex)
            raise(
              ArgumentError,
              "#{hex} already exists for als_id"
            )
          else
            super(hex)
          end
        end

        def generate_als_id
          while als_id.nil?
            uuid = SecureRandom.hex(9)
            self.als_id = uuid unless Hermes::HousingRequest.only(:als_id)
                                                            .find_by(als_id: uuid)
          end
        end
        before_create :generate_als_id
      end
      # module ClassMethods
      # end
    end
  end
end
