# frozen_string_literal: true

# app/hermes/models/concerns/common_field.rb
# app/controllers/concerns/test_concern.rb

module Hermes
  module Concerns
    module SopraXmlSender
      extend ActiveSupport::Concern

      included do

        field :last_xml_validation_report, type: String
        field :last_send_has_error, type: Boolean
        field :xml_sopra_error_ids, type: Array, default: []

        def add_error (error, path, params)

          playload =  params.length > 6000 ? params[0..6000] : params

          error_to_add = Hermes::XmlSopraError.create({
            item_id: self.id,
            item_class: self.class.name,
            path: path,
            playload: playload,
            error_content: error
          })

          errors_ids = xml_sopra_error_ids.push(error_to_add.id.to_s)

          if Rails.env == 'test'
            SaveSopraLogJob.perform_now(self.class.name, self.id.to_s, errors_ids.to_json)
          else
            SaveSopraLogJob.perform_later(self.class.name, self.id.to_s, errors_ids.to_json)
          end
        end

        def list_errors
          xml_sopra_error_ids.each do |error_id|
            ap Hermes::XmlSopraError.find(error_id)
          end
        end

        def validate_xml(xml, xsd)
          if HERMES_CONFIG['flux_debug'].to_bool
            schema_path = [Hermes::Engine.root, %w[spec libs bo_client tasks], xsd].flatten.join('/').to_s
    
            xsd = Nokogiri::XML::Schema(File.read(schema_path))
            xml_validation = xsd.validate(Nokogiri::XML(xml))
            self.set(last_xml_validation_report:  xml_validation.to_s, updated_at: DateTime.current)
            xml_validation.to_s
          end
        end

        def parse_xml(xml_string)
          Hash.from_xml(xml_string.gsub("\n", ""))
        end
      end
    end
  end
end
