class Hermes::EntityReservation
  include Mongoid::Document

  include Hermes::Concerns::CommonFieldsConcern
  include Hermes::Concerns::ActivableConcern
  field :entity_id, type: BSON::ObjectId
  field :housing_offer_id, type: BSON::ObjectId
  field :name, type: String
  field :from, type: DateTime
  field :to, type: DateTime

  common_indexes *%i[
    entity_id
    housing_offer_id
    name
    from
    to
  ]

  belongs_to(:housing_offer, class_name: 'Hermes::HousingOffer')
  belongs_to(:entity, class_name: 'Hermes::Entity')
  
  validates_presence_of :entity_id, :housing_offer_id, :from, :to
  
  owner_field :user_id

  before_save :before_save_actions
  after_save :after_save_actions

  @force_is_active = false

  def check_if_active(date = DateTime.now())
    (self.from.beginning_of_day .. self.to.end_of_day).cover?(date)
  end
  
  def update_activity(date = DateTime.now())
    self.is_active = check_if_active(date)
    if self.is_active_changed?
      @force_is_active = true
      self.save 
      @force_is_active = false
    end
  end

  def before_save_actions
    self.is_active = check_if_active if !@force_is_active
    update_rights
    true
  end

  def after_save_actions
    if is_active_changed?
      status = Hermes::Status.create(
        reference_model_name: "HousingOffer",
        status_label: "entity_status",
        motive: is_active ? "Est entré en période de réservation" : "La période de réservation a prit fin",
        title: is_active ? "Réservé par #{entity.title}" : "Fin de réservation pour #{entity.title}",
        object_id: housing_offer_id,
        performer_id: entity_id,
      )

      is_active ? housing_offer.active_reservations.push(entity_id.to_s) : housing_offer.active_reservations.delete(entity_id.to_s)
      housing_offer.reserved = housing_offer.active_reservations.length > 0
      housing_offer.save
    end
  end

  def update_rights
    if self.user_id.nil?
      self.user_id = entity.user_id
    end
  end
end
