# frozen_string_literal: true

module Hermes
  # HousingRequest serializer
  class HousingRequestFolderSerializer < Hermes::ApplicationSerializer
    cache key: proc { "#{object.cache_key}" }, expires_in: 1.day
    type 'housing_request_folders'
    
    attributes :nud_status,
               :consultation_status,
               :application_status,
               :completion,
               :validity_limit,
               :is_still_valid,
               :housing_request_id,
               :required_documents,
               :file_upload_from_sne_complete

    has_many :required_documents, serializer: RequiredDocumentSerializer do
      object.required_documents
    end
    
    def is_still_valid
      !!object.validity_limit && object.validity_limit > DateTime.now.to_date
    end
    
    def housing_request_id
      object.housing_request&.id&.to_s
    end
    
    def required_documents
      object.required_documents.sort_by{|rd| rd.ihm_order}.map do |doc|
        Hermes::RequiredDocumentSerializer.new(
          doc,
          scope: scope,
          root: false,
          base_url: instance_options[:base_url],
          folder_id: object.id,
          main_applicant_id: object.housing_request&.main_applicant_id
        )
      end
    end
  
  end
end
