require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')
  include Rack::Test::Methods
  
  describe Api::Dmo::PicturesController, :type => :api do
    
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper
    let!(:responsible) {create(:user, roles: ['Administrator'])}
    let!(:user) {create(:user)}
    let!(:housing_offer1) {create(:housing_offer, user_id: responsible.id)}
    let!(:picture0) {create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id)}
    let!(:picture1) {create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id)}
    let!(:picture2) {create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id)}
    let!(:picture3) {create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id)}
    
    #TESTS BASIQUES D'API
    
    describe 'POST /housing_offers/{:id}/pictures' do
      describe 'Create picture with minimal valid datas' do
        before :each do
          authenticated_header(request, responsible)
          post 'create', {
              id: housing_offer1.id.to_s
            
          }
        end
        it 'returns status code 201' do
          expect(response).to have_http_status(201)
          ho = Hermes::HousingOffer.find_by(id: json["data"]["attributes"]["housing_offer_id"])
          expect(ho.ordered_picture_ids.length).to eq 5
          expect(
              Hermes::HousingOfferSerializer.new(
                  ho,
                  scope: responsible,
                  root: true
              ).attributes[:pictures_nb]
          ).to eq(5)
        end
      end
      describe 'Create 6eme picture throw err' do
        let!(:picture5) {create(:picture, housing_offer_id: housing_offer1.id.to_s, user_id: responsible.id)}
        
        before :each do
          authenticated_header(request, responsible)
          post 'create', {
              id: housing_offer1.id.to_s
            
          }
        end
        it 'returns status code 224' do
          expect(response).to have_http_status(422)
        
        end
      end
    end
  end
end