require 'rails_helper'

RSpec.describe Hermes::HousingRequestInitializer, type: :model do
  context 'for structural tests' do
    
    it 'has a valid factory' do
      expect(FactoryBot.build(:housing_request_initializer, unique_number: "0540418098300AL004")).to be_valid
    end
  end
  
  context 'with basic objects' do

    let!(:hri) {create(:housing_request_initializer, unique_number: "0540418098300AL004")}
    
    
    context 'pin code functionality' do
      
      #config.action_mailer.delivery_method = :test
      describe 'pin code generation and email sending' do
        before :each do
          hri.send_pin_code_on_mail
        end
        it 'has save the pin code' do
          hri.reload
          expect(hri.hashed_pin_code).not_to be_empty
          mail_jobs = enqueued_jobs.select {|job| job[:job] == ActionMailer::DeliveryJob}
         # expect(mail_jobs.length).to be >= 1
          mail = perform_enqueued_jobs {ActionMailer::DeliveryJob.perform_now(*mail_jobs.first[:args])}
          expect(mail).not_to eq(nil)
        end
      end
      describe 'pin code verification' do
        it 'validate pin code' do
          pin = hri.send_pin_code_on_mail
          hri.reload
          expect(hri.check_pin_code(pin)).to eq(true)
        end
      end
    end
  end
end
