require 'rails_helper'
require 'vcr_config'

RSpec.describe Hermes::Nud, type: :model do
  context 'for structural tests' do
    let(:applicant) { create(:applicant) }
    let(:request) { create(:housing_request, main_applicant: applicant) }

    it 'has a valid factory' do
      expect(FactoryBot.build(:nud, housing_request: request)).to be_valid
    end
  end

  context 'with basic objects' do
    let!(:applicant1) { create(:applicant) }
    let!(:request1) { create(:housing_request, main_applicant: applicant1) }
    let!(:nud1) do
      create(
        :nud,
        housing_request: request1,
        department: '12',
        unique_number: '123456789',
        creation_date: '2016-23-14T14:53:22'
      )
    end
    let!(:nud2) do
      create(
        :nud,
        housing_request: request1,
        department: '12',
        creation_date: '2013-23-14T14:53:22'
      )
    end
    let!(:nud3) do
      create(
        :nud,
        housing_request: request1,
        department: '14',
        creation_date: '2017-23-14T14:53:22'
      )
    end

    describe 'side effects are correct' do
      it 'should has valide nud_creations for request1' do
        nud_creations = request1.reload.nud_creations
        { '12' => nud2, '14' => nud3 }.each do |key, nud|
          expect(nud_creations[key]).to(
            eq(nud.reload.creation_date)
          )
        end
      end

      let!(:applicant) { create(:applicant) }
      let!(:request) { create(:housing_request, main_applicant: applicant) }
      let!(:unique_number) { '123456789012345678' }
      let!(:nud) { create(:nud, unique_number: unique_number, housing_request: request, department: '12', creation_date: '2016-23-14T14:53:22') }

      it 'should notify applicant after creation' do
        drain_all_jobs
        expect(applicant.notifications.count).to eq(1)
        expect(request1.reload.sne_created_at).to eq(nud3.creation_date)
        notif = applicant.notifications.last
        expect(notif.key).to eq(NOTIFICATION_KEYS[:nud][:create])
        expect(notif.title).to eq("Numéro d'identification unique")
        expect(notif.body).to eq("Saisie validée : obtention de votre numéro unique + Pièces justificatives validées. Vous pouvez consulter les offres")
      end
    end

    it 'delete nud delete unique_numbers' do 
      expect{nud1.destroy}.to change{request1.reload.unique_numbers.include?(nud1.unique_number)}.from(true).to(false)
    end 
  end
end
